/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.risk;

import com.yiring.app.domain.workArea.WorkArea;
import com.yiring.common.domain.BasicEntity;
import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldNameConstants;
import lombok.experimental.SuperBuilder;
import org.hibernate.annotations.Comment;
import org.locationtech.jts.geom.Point;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/20 17:19
 */
@Getter
@Setter
@ToString
@SuperBuilder(toBuilder = true)
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@Entity
@Table(name = "BS_RISK_WARN", uniqueConstraints = @UniqueConstraint(columnNames = { "locationNum" }))
@Comment("风险预警")
public class RiskWarn extends BasicEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = 1345477064611048638L;

    @Comment("所属工区")
    @ManyToOne
    @JoinColumn(name = "workArea_id")
    private WorkArea workArea;

    @Comment("安装位置")
    private String install;

    @Comment("经纬度")
    @Column(columnDefinition = "geometry(Point,4326)")
    private Point point;

    @Comment("监控参数")
    private String monitoring;

    @Comment("位号")
    private String locationNum;

    @Comment("量程起始值")
    private BigDecimal min;

    @Comment("量程结束值")
    private BigDecimal max;

    @Comment("量程单位")
    private String unit;

    @Comment("启用")
    private Boolean enable;

    @ToString.Exclude
    @Comment("阈值区间信息")
    @Builder.Default
    @OneToMany(mappedBy = "riskWarn")
    private List<Threshold> thresholds = new ArrayList<>();
}
